-------------------------------------------------------------------------------
-- MrCurrency
--
-- Data Broker source for Currency
--
-- Send suggestions, comments, and bugs to user@zedonline.net
-------------------------------------------------------------------------------

local MRCData = {};
LibStub("AceAddon-3.0"):GetAddon("MrCurrency").Data = MRCData;

-- These are only visible to characters that have actually gotten one in the past.
-- So querying GetCurrencyInfo(402) doesn't return anything useful on a character 
-- that's never gotten a Chef's Award.
-- Shouldn't "GetCurrencyListInfo()" return these IDs as well?											
local CurrencyIds = {
	[61] = true, -- Dalaran Jewelcrafter's Token
	-- Dalaran Cooking Award (???)
	[241] = true, -- Champion's Seal
	[390] = true, -- Conquest Points
	[392] = true, -- Honor Points
	[395] = true, -- Justice Points
	-- Valor Points (NYI? 396?)
	[402] = true, -- Chef's Award
}		

-- Note: These can currently be gotten by querying Archaeology APIs.
-- Do we really need to keep a copy in the code for any reason?
local ArchaeologyCurrencies = {
	[384] = true, -- Dwarf
	[385] = true, -- Troll
	[393] = true, -- Fossil
	[394] = true, -- Night Elf
	[397] = true, -- Orc
	[398] = true, -- Draenei
	[399] = true, -- Vrykul
	[400] = true, -- Nerubian
	[401] = true, -- Tol'vir
}

-- Default DB information
-- Version: 1
local Defaults = {
	global = {
		version = 1,
		currency = {},
	},
	realm = {
		players = {},
	},
};

function MRCData:Load()
	self.db = LibStub("AceDB-3.0"):New("MrCurrencyDB", Defaults, "Default");
end

function MRCData:GetKnownCurrencyList()	
	return self.db.global.currency;
end

function MRCData:GetCurrencyInfo(playerName)
	if( playerName ) then
		return self.db.realm.players[playerName];
	else
		return self.db.realm.players;
	end
end

function MRCData:StoreCurrencyInfo(money, currencies)
	local playerName = UnitName("player");
	local playerFaction = UnitFactionGroup("player");
	local playerEntry = self:GetPlayerEntry(playerName);
	
	playerEntry["_money"] = money;
	playerEntry["_faction"] = playerFaction;
	
	for _, currency in ipairs(currencies) do
		playerEntry[currency.icon] = currency.count;		
		self:AddNewCurrency(currency.name, currency.icon);
	end
	
	self.db.realm.players[playerName] = playerEntry;
end

function MRCData:GetArchaeologyTracking(currencyId, playerName)
	local playerEntry = self:GetPlayerEntry(playerName);
	local trackingInfo = playerEntry["_trackingArchaeology"] or {};
	
	if( trackingInfo[currencyId] == nil ) then
		return true;
	end
	
	return trackingInfo[currencyId];
end

function MRCData:SetArchaeologyTracking(currencyId, shouldTrack)
	local playerEntry = self:GetPlayerEntry();
	local trackingInfo = playerEntry["_trackingArchaeology"] or {};
	
	-- Propogate back into the database
	trackingInfo[currencyId] = shouldTrack;
	playerEntry["_trackingArchaeology"] = trackingInfo;
end

function MRCData:GetCurrencyEntry(currencyId)
	for _, currency in ipairs(self.db.global.currency) do
		if( currency.icon == currencyId ) then
			return currency;
		end
	end
	
	return nil;
end

function MRCData:AddNewCurrency(name, icon)
	if( self:GetCurrencyEntry(icon) == nil ) then
		self.db.global.currency[#self.db.global.currency+1] = {
			["name"] = name,
			["icon"] = icon,
		};
	end
end

function MRCData:GetPlayerEntry(playerName)
	if( playerName == nil ) then
		playerName = UnitName("player");
	end
	
	if( self.db.realm.players[playerName] == nil ) then
		self.db.realm.players[playerName] = {};
	end
	
	return self.db.realm.players[playerName];
end
